@@ -106,6 +106,15 @@ sorted_classifiers = [
     "Framework :: IDLE",
     "Framework :: IPython",
     "Framework :: Jupyter",
+    "Framework :: Jupyter :: JupyterLab",
+    "Framework :: Jupyter :: JupyterLab :: 1",
+    "Framework :: Jupyter :: JupyterLab :: 2",
+    "Framework :: Jupyter :: JupyterLab :: 3",
+    "Framework :: Jupyter :: JupyterLab :: 4",
+    "Framework :: Jupyter :: JupyterLab :: Extensions",
+    "Framework :: Jupyter :: JupyterLab :: Extensions :: Mime Renderers",
+    "Framework :: Jupyter :: JupyterLab :: Extensions :: Prebuilt",
+    "Framework :: Jupyter :: JupyterLab :: Extensions :: Themes",
     "Framework :: Kedro",
     "Framework :: Lektor",
     "Framework :: Masonite",
@@ -162,6 +171,7 @@ sorted_classifiers = [
     "Framework :: Zope :: 3",
     "Framework :: Zope :: 4",
     "Framework :: Zope :: 5",
+    "Framework :: aiohttp",
     "Framework :: napari",
     "Framework :: tox",
     "Intended Audience :: Customer Service",
